@@ -1,5 +1,8 @@
 fn main() {
-    vviz::app::spawn(|mut manager: vviz::manager::Manager| {
+    use clap::Parser;
+    let args = vviz::app::Args::parse();
+
+    vviz::app::spawn(args.mode, |mut manager: vviz::manager::Manager| {
         let w3d = manager.add_widget3("w3d".to_string());
         w3d.place_entity_at(
             "cube".to_string(),
