@@ -1,12 +1,14 @@
 //! The app entry point.
 
+use clap::Parser;
+
 use super::common;
 use super::gui;
 use super::manager;
 
 struct App {
-    to_gui_loop_receiver: Option<std::sync::mpsc::Receiver<Box<dyn common::ToGuiLoopMessage>>>,
-    from_gui_loop_sender: Option<std::sync::mpsc::Sender<Box<dyn common::FromGuiLoopMessage>>>,
+    to_gui_loop_receiver: Option<std::sync::mpsc::Receiver<common::ToGuiLoopMessage>>,
+    from_gui_loop_sender: Option<std::sync::mpsc::Sender<common::FromGuiLoopMessage>>,
 }
 
 impl App {
@@ -25,7 +27,7 @@ impl App {
         self.from_gui_loop_sender = Some(from_gui_loop_sender);
 
         std::thread::spawn(move || {
-            let manager = manager::Manager::new(to_gui_loop_sender, from_gui_loop_receiver);
+            let manager = manager::Manager::new_local(to_gui_loop_sender, from_gui_loop_receiver);
             f(manager);
         });
         self.block_on_gui_loop();
@@ -49,11 +51,29 @@ impl App {
     }
 }
 
-/// This spawns the main application thread - which one whishes to visually/interactively debug.
+/// Visualization mode
+#[derive(Clone, Debug, PartialEq, clap::ArgEnum)]
+pub enum VVizMode {
+    /// Create a local GUI window and render loop for visualization.
+    Local,
+    /// Connect via websocket to remote app.
+    Remote,
+}
+
+/// Application arguments
+#[derive(Parser, Debug)]
+#[clap(author, version, about, long_about = None)]
+pub struct Args {
+    /// visualization mode
+    #[clap(short, long, arg_enum)]
+    pub mode: VVizMode,
+}
+
+/// This spawns the application thread - which one whishes to visually/interactively debug.
 ///
 /// Example
 /// ``` no_run
-/// vviz::app::spawn(|mut manager: vviz::manager::Manager| {
+/// vviz::app::spawn(vviz::app::VVizMode::Local, |mut manager: vviz::manager::Manager| {
 ///     let mut ui_a_button = manager.add_button("a button".to_string());
 ///
 ///     // Some initial application logic...
@@ -69,7 +89,15 @@ impl App {
 ///     }
 /// });
 /// ```
-pub fn spawn(f: impl FnOnce(manager::Manager) + Send + 'static) {
-    let vviz = App::new();
-    vviz.spawn(f)
+pub fn spawn(mode: VVizMode, f: impl FnOnce(manager::Manager) + Send + 'static) {
+    match mode {
+        VVizMode::Local => {
+            let vviz = App::new();
+            vviz.spawn(f);
+        }
+        VVizMode::Remote => {
+            let manager = manager::Manager::new_remote();
+            f(manager);
+        }
+    }
 }
